@@ -323,14 +323,14 @@ class PMA_Theme
     {
         if (is_null($file)) {
             return $this->img_path;
-        } else {
-            if (is_readable($this->img_path . $file)) {
-                return $this->img_path . $file;
-            } else {
-                return $GLOBALS['cfg']['ThemePath'] . '/'
-                    . PMA_Theme_Manager::FALLBACK_THEME . '/img/' . $file;
-            }
         }
+
+        if (is_readable($this->img_path . $file)) {
+            return $this->img_path . $file;
+        }
+
+        return $GLOBALS['cfg']['ThemePath'] . '/'
+            . PMA_Theme_Manager::FALLBACK_THEME . '/img/' . $file;
     }
 
     /**
@@ -433,9 +433,6 @@ class PMA_Theme
         if (!is_null($fs)) {
             return $fs;
         }
-        if (isset($_COOKIE['pma_fontsize'])) {
-            return htmlspecialchars($_COOKIE['pma_fontsize']);
-        }
         return '82%';
     }
 
