@@ -396,7 +396,9 @@ class FormDisplay
 
         // detect password fields
         if ($type === 'text'
-            && /*overload*/mb_substr($translated_path, -9) === '-password'
+            && (mb_substr($translated_path, -9) === '-password'
+               || mb_substr($translated_path, -4) === 'pass'
+               || mb_substr($translated_path, -4) === 'Pass')
         ) {
             $type = 'password';
         }
@@ -592,11 +594,13 @@ class FormDisplay
                 // cast variables to correct type
                 switch ($type) {
                 case 'double':
+                    $_POST[$key] = PMA_Util::requestString($_POST[$key]);
                     settype($_POST[$key], 'float');
                     break;
                 case 'boolean':
                 case 'integer':
                     if ($_POST[$key] !== '') {
+                        $_POST[$key] = PMA_Util::requestString($_POST[$key]);
                         settype($_POST[$key], $type);
                     }
                     break;
@@ -613,7 +617,7 @@ class FormDisplay
                     break;
                 case 'string':
                 case 'short_string':
-                    $_POST[$key] = trim($_POST[$key]);
+                    $_POST[$key] = PMA_Util::requestString($_POST[$key]);
                     break;
                 case 'array':
                     // eliminate empty values and ensure we have an array
@@ -827,7 +831,7 @@ class FormDisplay
     private function _fillPostArrayParameters($post_values, $key)
     {
         foreach ($post_values as $v) {
-            $v = trim($v);
+            $v = PMA_Util::requestString($v);
             if ($v !== '') {
                 $_POST[$key][] = $v;
             }
